@@ -82,6 +82,7 @@ func (a *Artifact) TryMakeRequest(w http.ResponseWriter, r *http.Request, token
 	return true
 }
 
+//nolint:gocyclo // multiple conditions required for headers handling
 func (a *Artifact) makeRequest(w http.ResponseWriter, r *http.Request, reqURL *url.URL, token string, additionalHandler func(*http.Response) bool) {
 	req, err := http.NewRequestWithContext(r.Context(), "GET", reqURL.String(), nil)
 	if err != nil {
@@ -137,7 +138,9 @@ func (a *Artifact) makeRequest(w http.ResponseWriter, r *http.Request, reqURL *u
 	}
 
 	w.Header().Set("Content-Type", resp.Header.Get("Content-Type"))
-	w.Header().Set("Content-Encoding", resp.Header.Get("Content-Encoding"))
+	if resp.Header.Get("Content-Encoding") != "" {
+		w.Header().Set("Content-Encoding", resp.Header.Get("Content-Encoding"))
+	}
 
 	// If the API uses chunked encoding, it will omit the Content-Length Header.
 	// Go uses a value of -1, which is an invalid value.
