@@ -162,6 +162,9 @@ func TestTryMakeRequest(t *testing.T) {
 			require.Equal(t, c.ContentType, result.Header().Get("Content-Type"))
 			require.Equal(t, c.Length, result.Header().Get("Content-Length"))
 			require.Equal(t, c.CacheControl, result.Header().Get("Cache-Control"))
+			if c.ContentEncoding == "" {
+				require.Equal(t, 0, len(result.Header().Values("Content-Encoding")))
+			}
 			require.Equal(t, c.ContentEncoding, result.Header().Get("Content-Encoding"))
 			require.Equal(t, c.Content, result.Body.String())
 		})
